@@ -3,7 +3,7 @@ import os.path
 
 
 @pytest.fixture(scope="module")
-def sample_report_path() -> str:
+def sample_reports_path() -> str:
     return os.path.abspath(
         os.path.join(os.path.dirname(__file__), "..", "sample-reports")
     )
